/***** interface.c ************************************************
 * Description: Routine for gathering arguments from the command
 *              line.
 * Author: Bernhard Haubold, bernhard.haubold@fh-weihenstephan.de
 * File created on Sun Jun 20 13:12:10 2004.
 *
 * This file is part of shulen.
 *
 *   Shulen is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   Shulen is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with shulen; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *****************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "eprintf.h"
#include "interface.h"

Args getArgs(int argc, char *argv[]){
  Args args;
  char c;
  int arg, nargs;

  args.h = 0;
  args.e = 0;
  args.s = 0;
  args.r = 0;
  args.P = 0;
  args.p = 0.5;
  args.l = 0;
  nargs = 0;
  arg = 1;
  args.argv = (char *)emalloc(MAXLINE*sizeof(char));
  args.argv[0] = '\0';
  while(arg < argc){
    args.argv = strcat(args.argv," ");
    args.argv = strcat(args.argv,argv[arg]);
    c = argv[arg][1];
      switch(c){
      case 'p': 
	args.p = (float)atof(argv[++arg]);
	args.argv = strcat(args.argv," ");
	args.argv = strcat(args.argv,argv[arg]);
	nargs++;
	break;
      case 'l':
	args.l = atof(argv[++arg]);
	args.argv = strcat(args.argv," ");
	args.argv = strcat(args.argv,argv[arg]);
	nargs++;
	break;
      case 'P':
	args.P = 1;
	break;
      case 's':
	args.s = atoi(argv[++arg]);
	args.argv = strcat(args.argv," ");
	args.argv = strcat(args.argv,argv[arg]);
	nargs++;
	break;
      case 'r':
	args.r = 1;
	break;
      case 'h':
	args.h = 1;
	break;
      default:
	printf("# unknown argument: %c\n",c);
	args.e = 1;
	return args;
      }
      arg++;
  }
  if(nargs < 2)
    args.e = 1;
  return args;
}

void printUsage(char *version){
  printf("shulen version %s, copyright (c) 2005, Bernhard Haubold & Thomas Wiehe\n", version);
  printf("purpose: compute the null distribution of shustring lengths for nucleotide sequences\n");
  printf("usage: shulen [options]\n");
  printf("options\n");
  printf("\t-l <NUM> genome consists of NUM nucleotides\n");
  printf("\t-p <NUM> g/c-content of genome is NUM\n");
  printf("\t[-r include reverse complement; default: consider only forward strand]\n");
  printf("\t[-s print expectation value for shustring of length s]\n");
  printf("\t[-P print information about program]\n");		
  printf("\t[-h print this help message]\n");
}

void printSplash(char *version){
  printf("********************************************\n");
  printf("*       SHULEN %s - Shustring Lengths     *\n",version);
  printf("*                    by                    *\n");
  printf("*      Bernhard Haubold & Thomas Wiehe     *\n");
  printf("*------------------------------------------*\n");
  printf("*               REFERENCE                  *\n");
  printf("* Haubold, B., Pierstorff, N., M\"oller,    *\n");
  printf("* F., Wiehe, T. (2005). Genome comparison  *\n");
  printf("* without alignment using shortest unique  *\n");
  printf("* substrings. BMC Bioinformatics, in       *\n");
  printf("* press.                                   *\n");
  printf("*              CONTACT                     *\n");
  printf("* Code maintained by Bernhard Haubold,     *\n");
  printf("* bernhard.haubold@fh-weihenstephan.de     *\n");
  printf("*              LICENSE                     *\n");
  printf("* SHULEN is distributed under the GNU      *\n");
  printf("* General Public License. You should have  *\n");
  printf("* received a copy of the licence together  *\n");
  printf("* with this software. If not, see          *\n");
  printf("* http://www.gnu.org/licenses/.            *\n");
  printf("********************************************\n");
}
