/***** shulen.c ***************************************************
 * Description: Compute the null distribution of shustring lengths
 *              given a genome length and G/C-content.
 * Author: Bernhard Haubold, bernhard.haubold@fh-weihenstephan.de
 * File created on Sun Jun 20 13:03:03 2004.
 *
 * This file is part of shulen.
 *
 *   Shulen is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   Shulen is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with shulen; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *****************************************************************/
#include <stdio.h>
#include <math.h>
#include "shulen.h"
#include "interface.h" 

double sum(double x, double p, double l);

int main(int argc, char *argv[]){
  Args args;
  double cp;      /* cumulative probability */
  double p;       /* G/C-content */
  double prob;    /* probability */
  double m;       /* mean shustring length */
  double l;       /* genome length */
  double e;       /* expected number of shustrings */
  double x;       /* current shustring length */
  char *version;  /* program version */

  version = "1.0";
  args = getArgs(argc, argv);

  if(args.h == 1){
    printUsage(version);
    return 0; 
  }else if(args.P){
    printSplash(version);
    return 0;
  }else if(args.e == 1){
    printUsage(version);
    return -1;
  }


  p = args.p;
  if(!args.r)
    l = args.l;
  else
    l = args.l*2;
  cp = 0.0;
  x = 0;
  printf("# commandline: shulen%s\n",args.argv);
  printf("# shulen\tp\tcp\texp\n");
  
  m = 0.0;
  while(cp < 1.0){
    x++;
    prob = sum(x,p,l) - sum(x-1,p,l);
    if(prob < 0)
      prob = 0;
    cp += prob;
    m += (double)x * prob;
    e = l * prob;
    if(e >= 1)
      printf("%d\t%f\t%e\t%e\n",(int)x,prob,cp,e);
  }
  printf("# mean_shustring_length = %f\n",m);
  if(args.s > 0){
    x = args.s;
    e = sum(x,p,l) - sum(x-1,p,l);
    printf("# E(l=%d) = %e\n",args.s,e*l);
  }

  return 0;
}


/* Compute sum in formula */
double sum(double x, double p, double l){
  double s;
  double k;

  s = 0.0;
  
  for(k=0; k<=x; k++){
    s += pow(2.0,x)*pow((1.0-p)/2.0,x-k)*pow(p/2.0,k)*pow(1.0-pow((1.0-p)/2.0,x-k)*pow(p/2.0,k),l-1.0)*binomial(x,k);
  }
  if(s>1.0)
    s=1.0;
  return s;

}
